@@ -34,6 +34,8 @@ import smtplib
 import json
 from collections import namedtuple
 
+from azure.storage.blob import BlobClient
+
 from docopt import docopt
 import requests
 
@@ -97,9 +99,10 @@ PRODUCTS = {
     "ATS9628": '1047',
     "ATS9870": '3',
     "ATS9872": '1042',
-    "ATST371": '1044',
+    #"ATST371": '1044',
     "ATST352": '1045',
     "ATST146": '1046',
+    "ATST364": '3009',
     # Negative product IDs are for products that we want to send to the website 
     # but are to be associated with other products. For instance, some packages 
     # are to be sent to Linux drivers resources.
@@ -181,6 +184,10 @@ def get_french_name(packageid):
         return "Utilitaire de mise à jour de micrologiciel (GUI)"
     return packageid.key
 
+def get_md5_content(installer):
+    blob = BlobClient.from_blob_url(installer) 
+    return str(blob.get_blob_properties().content_settings.content_md5)
+
 def get_category(key):
     if is_driver(key):
         return 'driver'
@@ -196,6 +203,16 @@ def get_product_key(filename):
             return key
     raise ValueError("Could not identify product for file {}".format(filename))
 
+def get_thunderbolt_equivalent(drv_key):
+    if is_driver(drv_key):
+        tb_key = drv_key.replace(drv_key[0:4], "ATST", 1)
+        for key in PRODUCTS:
+            if key == tb_key:
+                return tb_key
+    return ''
+
+    
+
 
 # The file and optional release notes associated with a package
 Package = namedtuple(
@@ -245,6 +262,20 @@ def packages_from_files(files):
                     arch=packageid.arch,
                     category=get_category(packageid.key),
                     name_french=get_french_name(packageid)))
+
+        tb_key = get_thunderbolt_equivalent(packageid.key)
+        if tb_key != '':
+            tb_packageid = PackageId(tb_key, packageid.os, packageid.arch)
+            packages.append(
+                Package(os=tb_packageid.os,
+                        product_id=PRODUCTS[tb_packageid.key],
+                        installer=installers[packageid],
+                        readme=readmes[packageid.key],
+                        name=get_name(tb_packageid),
+                        arch=tb_packageid.arch,
+                        category=get_category(tb_packageid.key),
+                        name_french=get_french_name(tb_packageid)))
+
     return packages
 
 # Packages to be sent to Linux drivers resources.
@@ -279,6 +310,7 @@ def payload_from_packages(packages, base_url, version, password):
                         "arch": package.arch,
                         "category": package.category,
                         "name_french": package.name_french,
+                        "id": get_md5_content(base_url + package.installer) + "_" + PRODUCTS[key],
                     })
         if not package.product_id.startswith('-'):
             payload.append({
@@ -292,6 +324,7 @@ def payload_from_packages(packages, base_url, version, password):
                 "arch": package.arch,
                 "category": package.category,
                 "name_french": package.name_french,
+                "id": get_md5_content(base_url + package.installer) + "_" + package.product_id,
             })
     return json.dumps(payload)
 
